// syscall.h -- Defines the interface for and structures relating to the syscall dispatch system.
//              Written for JamesM's kernel development tutorials.

#ifndef SYSCALL_H
#define SYSCALL_H

#include "common.h"
void initialise_syscalls();

#define DECL_SYSCALL0(fn) int k##fn();
#define DECL_SYSCALL1(fn,p1) int k##fn(p1);
#define DECL_SYSCALL2(fn,p1,p2) int k##fn(p1,p2);
#define DECL_SYSCALL3(fn,p1,p2,p3) int k##fn(p1,p2,p3);
#define DECL_SYSCALL4(fn,p1,p2,p3,p4) int k##fn(p1,p2,p3,p4);
#define DECL_SYSCALL5(fn,p1,p2,p3,p4,p5) int k##fn(p1,p2,p3,p4,p5);

#define DEFN_SYSCALL0(fn, num) \
int k##fn() \
{ \
  int a; \
  asm volatile("int $0x90" : "=a" (a) : "0" (num)); \
  return a; \
}

#define DEFN_SYSCALL1(fn, num, P1) \
int k##fn(P1 p1) \
{ \
  int a; \
  asm volatile("int $0x90" : "=a" (a) : "0" (num), "b" ((int)p1)); \
  return a; \
}

#define DEFN_SYSCALL2(fn, num, P1, P2) \
int k##fn(P1 p1, P2 p2) \
{ \
  int a; \
  asm volatile("int $0x90" : "=a" (a) : "0" (num), "b" ((int)p1), "c" ((int)p2)); \
  return a; \
}

#define kDEFN_SYSCALL3(fn, num, P1, P2, P3) \
int ##fn(P1 p1, P2 p2, P3 p3) \
{ \
  int a; \
  asm volatile("int $0x90" : "=a" (a) : "0" (num), "b" ((int)p1), "c" ((int)p2), "d"((int)p3)); \
  return a; \
}

#define DEFN_SYSCALL4(fn, num, P1, P2, P3, P4) \
int k##fn(P1 p1, P2 p2, P3 p3, P4 p4) \
{ \
  int a; \
  asm volatile("int $0x90" : "=a" (a) : "0" (num), "b" ((int)p1), "c" ((int)p2), "d" ((int)p3), "S" ((int)p4)); \
  return a; \
}

#define DEFN_SYSCALL5(fn, num) \
int k##fn(P1 p1, P2 p2, P3 p3, P4 p4, P5 p5) \
{ \
  int a; \
  asm volatile("int $0x90" : "=a" (a) : "0" (num), "b" ((int)p1), "c" ((int)p2), "d" ((int)p3), "S" ((int)p4), "D" ((int)p5)); \
  return a; \
}

// I must do this for every system call I'm registering.

#define MAX_SYSCALLS	8

DECL_SYSCALL1(puts, const char*)
DECL_SYSCALL1(put_hex, const char*)
DECL_SYSCALL1(put_dec, const char*)
DECL_SYSCALL2(set_colors, u8int, u8int)
DECL_SYSCALL1(putc, const char)
DECL_SYSCALL0(clear_screen)
DECL_SYSCALL2(move_cursor, int, int)
DECL_SYSCALL1(gets, char*)
#endif
